==> 0.0.11.tar.gz: lib/widget/dialog/custom_dialog_warning_one_button.dart <==
import '../../common/values/colors.dart';
import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import '../custom/custom_icon.dart';
import '../custom/spaces.dart';
import '../text/custom_text_header_medium_field.dart';
import '../text/custom_text_medium_field.dart';
import 'package:flutter/material.dart';

class CustomDialogOne extends StatelessWidget {
  final String? title, code;
  final List<String>? content;
  final String negativeBtnText;
  final GestureTapCallback positiveBtnPressed;
  final Widget? iconWarning;
  final Color? colorWarning;
  final bool? isClose;

  CustomDialogOne({
    required this.title,
    required this.negativeBtnText,
    required this.positiveBtnPressed,
    this.content,
    this.isClose = true,
    required this.iconWarning,
    this.code,
    this.colorWarning = SharingColors.ErrorColor,
  });

  @override
  Widget build(BuildContext context) {
    return Dialog(
      elevation: 0,
      backgroundColor: Colors.transparent,
      child: _buildDialogContent(context),
    );
  }

  Widget _buildDialogContent(BuildContext context) {
    return WillPopScope(
        onWillPop: () async {
          Navigator.of(context, rootNavigator: true).pop();
          return Future.value(false);
        },
        child: Stack(
          alignment: Alignment.topCenter,
          children: <Widget>[
            Container(
              margin: EdgeInsets.only(top: 40),
              decoration: BoxDecoration(
                  color: Colors.white, borderRadius: BorderRadius.circular(10)),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  Container(
                    width: Sizes.width(context),
                    height: 52,
                    decoration: BoxDecoration(
                      color: colorWarning,
                      borderRadius: BorderRadius.only(
                          topLeft: Radius.circular(10),
                          topRight: Radius.circular(10)),
                    ),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: [
                        CustomTextHeaderMediumField(
                          label: title,
                          align: TextAlign.center,
                          color: Colors.white,
                        ),
                        SpaceW8(),
                        iconWarning ??
                            CustomIcon(
                              icon: Icons.warning,
                              color: Colors.white,
                              size: 24,
                            )
                      ],
                    ),
                  ),
                  SpaceH10(),
                  content != null
                      ? Padding(
                          padding: const EdgeInsets.symmetric(horizontal: 8),
                          child: CustomTextMediumField(
                            label: content
                                .toString()
                                .replaceAll("[", "")
                                .replaceAll("]", ""),
                            align: TextAlign.center,
                            maxLine: 6,
                          ),
                        )
                      : Container(),
                  SpaceH10(),
                  TextButton(
                    child: Text(negativeBtnText,
                        style: Styles.customTextMediumStyle(
                            color: Theme.of(context).primaryColorLight)),
                    onPressed: positiveBtnPressed,
                  ),
                ],
              ),
            ),
          ],
        ));
  }
}

==> 0.0.24.tar.gz: lib/widget/dialog/custom_dialog_warning_one_button.dart <==
import '../../common/values/colors.dart';
import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import '../custom/custom_icon.dart';
import '../custom/spaces.dart';
import '../text/custom_text_header_medium_field.dart';
import '../text/custom_text_medium_field.dart';
import 'package:flutter/material.dart';

class CustomDialogOne extends StatelessWidget {
  final String? title, code;
  final List<String>? content;
  final String negativeBtnText;
  final GestureTapCallback positiveBtnPressed;
  final Widget? iconWarning;
  final Color? colorWarning;
  final bool? isClose;

  CustomDialogOne({
    required this.title,
    required this.negativeBtnText,
    required this.positiveBtnPressed,
    this.content,
    this.isClose = true,
    required this.iconWarning,
    this.code,
    this.colorWarning = SharingColors.ErrorColor,
  });

  @override
  Widget build(BuildContext context) {
    return Dialog(
      elevation: 0,
      backgroundColor: Colors.transparent,
      child: _buildDialogContent(context),
    );
  }

  Widget _buildDialogContent(BuildContext context) {
    return WillPopScope(
        onWillPop: () async {
          Navigator.of(context, rootNavigator: true).pop();
          return Future.value(false);
        },
        child: Stack(
          alignment: Alignment.topCenter,
          children: <Widget>[
            Container(
              margin: EdgeInsets.only(top: 40),
              decoration: BoxDecoration(
                  color: Colors.white, borderRadius: BorderRadius.circular(10)),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  Container(
                    width: Sizes.width(context),
                    height: 52,
                    decoration: BoxDecoration(
                      color: colorWarning,
                      borderRadius: BorderRadius.only(
                          topLeft: Radius.circular(10),
                          topRight: Radius.circular(10)),
                    ),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: [
                        CustomTextHeaderMediumField(
                          label: title,
                          align: TextAlign.center,
                          color: Colors.white,
                        ),
                        SpaceW8(),
                        iconWarning ??
                            CustomIcon(
                              icon: Icons.warning,
                              color: Colors.white,
                              size: 24,
                            )
                      ],
                    ),
                  ),
                  SpaceH10(),
                  content != null
                      ? Padding(
                          padding: const EdgeInsets.symmetric(horizontal: 8),
                          child: CustomTextMediumField(
                            label: content
                                .toString()
                                .replaceAll("[", "")
                                .replaceAll("]", ""),
                            align: TextAlign.center,
                            maxLine: 6,
                          ),
                        )
                      : Container(),
                  SpaceH10(),
                  TextButton(
                    child: Text(negativeBtnText,
                        style: Styles.customTextMediumStyle(
                            color: Theme.of(context).buttonColor)),
                    onPressed: positiveBtnPressed,
                  ),
                ],
              ),
            ),
          ],
        ));
  }
}
